@@ -168,6 +168,7 @@ impl Lavalink {
     ///
     /// [crate documentation]: crate#examples
     pub async fn process(&self, event: &Event) -> Result<(), ClientError> {
+        #[cfg(feature = "tracing")]
         tracing::trace!("processing event: {:?}", event);
 
         let guild_id = match event {
@@ -183,12 +184,14 @@ impl Lavalink {
                     self.server_updates.insert(guild_id, e.clone().into());
                     guild_id
                 } else {
+                    #[cfg(feature = "tracing")]
                     tracing::trace!("event has no guild ID: {:?}", e);
                     return Ok(());
                 }
             }
             Event::VoiceStateUpdate(e) => {
                 if e.0.user_id != self.user_id {
+                    #[cfg(feature = "tracing")]
                     tracing::trace!("got voice state update from another user");
 
                     return Ok(());
@@ -208,6 +211,7 @@ impl Lavalink {
                     }
                     guild_id
                 } else {
+                    #[cfg(feature = "tracing")]
                     tracing::trace!("event has no guild ID: {:?}", e);
                     return Ok(());
                 }
@@ -215,6 +219,7 @@ impl Lavalink {
             _ => return Ok(()),
         };
 
+        #[cfg(feature = "tracing")]
         tracing::debug!(
             "got voice server/state update for {:?}: {:?}",
             guild_id,
@@ -228,6 +233,7 @@ impl Lavalink {
                 (Some(server), Some(session)) => {
                     let server = server.value();
                     let session = session.value();
+                    #[cfg(feature = "tracing")]
                     tracing::debug!(
                         "got both halves for {}: {:?}; Session ID: {:?}",
                         guild_id,
@@ -236,6 +242,7 @@ impl Lavalink {
                     );
                     VoiceUpdate::new(guild_id, session.as_ref(), server.clone())
                 }
+                #[cfg(feature = "tracing")]
                 (Some(server), None) => {
                     tracing::debug!(
                         "guild {} is now waiting for other half; got: {:?}",
@@ -244,6 +251,7 @@ impl Lavalink {
                     );
                     return Ok(());
                 }
+                #[cfg(feature = "tracing")]
                 (None, Some(session)) => {
                     tracing::debug!(
                         "guild {} is now waiting for other half; got session ID: {:?}",
@@ -252,17 +260,24 @@ impl Lavalink {
                     );
                     return Ok(());
                 }
-                (None, None) => return Ok(()),
+                _ => return Ok(()),
             }
         };
 
+        #[cfg(feature = "tracing")]
         tracing::debug!("getting player for guild {}", guild_id);
+
         let player = self.player(guild_id).await?;
+
+        #[cfg(feature = "tracing")]
         tracing::debug!("sending voice update for guild {}: {:?}", guild_id, update);
+
         player.send(update).map_err(|source| ClientError {
             kind: ClientErrorType::SendingVoiceUpdate,
             source: Some(Box::new(source)),
         })?;
+
+        #[cfg(feature = "tracing")]
         tracing::debug!("sent voice update for guild {}", guild_id);
 
         Ok(())
